LibTorchDevice

Enum LibTorchDevice 

pub enum LibTorchDevice {
    Cpu,
    Cuda(usize),
    Mps,
    Vulkan,
}
The device struct when using the tch backend.

Note that you need to provide the device index when using Cuda.

Example

use burn_tch::LibTorchDevice;

let device_gpu_1 = LibTorchDevice::Cuda(0); // First GPU
let device_gpu_2 = LibTorchDevice::Cuda(1); // Second GPU
let device_cpu = LibTorchDevice::Cpu; // CPU
let device_mps = LibTorchDevice::Mps; // Metal Performance Shaders
let device_vulkan = LibTorchDevice::Vulkan; // Vulkan

Variants



Cpu

CPU device.



Cuda(usize)

Cuda device with the given index. The index is the index of the Cuda device in the list of all Cuda devices found on the system.



Mps

Metal Performance Shaders device.



Vulkan

Vulkan device.